summaryrefslogtreecommitdiffstats
path: root/vid-webpack-master/src/app/drawingBoard/service-planning/objectsToTree/models/configuration/configuration.model.info.ts
diff options
context:
space:
mode:
Diffstat (limited to 'vid-webpack-master/src/app/drawingBoard/service-planning/objectsToTree/models/configuration/configuration.model.info.ts')
-rw-r--r--vid-webpack-master/src/app/drawingBoard/service-planning/objectsToTree/models/configuration/configuration.model.info.ts11
1 files changed, 4 insertions, 7 deletions
diff --git a/vid-webpack-master/src/app/drawingBoard/service-planning/objectsToTree/models/configuration/configuration.model.info.ts b/vid-webpack-master/src/app/drawingBoard/service-planning/objectsToTree/models/configuration/configuration.model.info.ts
index 31c44390d..9845fb69b 100644
--- a/vid-webpack-master/src/app/drawingBoard/service-planning/objectsToTree/models/configuration/configuration.model.info.ts
+++ b/vid-webpack-master/src/app/drawingBoard/service-planning/objectsToTree/models/configuration/configuration.model.info.ts
@@ -26,14 +26,11 @@ export class ConfigurationModelInfo implements ILevelNodeInfo{
getType = () : string => "Configuration";
/***********************************************************
* return configuration model
* @param configurationModelId - current Model id
* @param serviceHierarchy - serviceHierarchy
************************************************************/
- getModel = (configurationModelId : string, serviceHierarchy) : any =>{
- const model = this._sharedTreeService.modelByIdentifiers(serviceHierarchy, this.name, configurationModelId);
- if (!_.isNil(model)) {
- return model;
+ getModel = (instanceModel: any) : any =>{
+ if (!_.isNil(instanceModel)) {
+ return instanceModel;
}
return {};
};
@@ -26,14 +26,11 @@ export class ConfigurationModelInfo implements ILevelNodeInfo{
getType = () : string => "Configuration";
/***********************************************************
- * return configuration model
- * @param configurationModelId - current Model id
- * @param serviceHierarchy - serviceHierarchy
+ * @param instanceModel - The model of the instance (usually extracted from serviceHierarchy store)
************************************************************/